@@ -25,9 +25,10 @@ from StringIO import StringIO
 
 class Connection:
     spinner = ['\\', '|', '/', '-']
-    def __init__(self, server, auth):
-        self.server = server
-        self.auth = auth
+    def __init__(self, conf):
+        self.conf = conf
+        self.server = conf.server
+        self.auth = conf.auth
         self.force = False
         self.paste = False
         self.review = False
@@ -68,12 +69,21 @@ class Connection:
 
         return newcourse
 
-    def get_exercise(self, course_id, exercise_id):
-        course = self.get_course(course_id)
-        for i in course.exercises:
-            if i.id == exercise_id:
-                return i
-        v.log(-1, "Could not find exercise %d in course %d" % (exercise_id, course_id))
+    def get_exercise(self, exercise):
+        r = requests.get("%sexercises/%d.json" % (self.server, exercise),
+            headers=self.auth,
+            params={"api_version": 7})
+
+        data = self.extract_json(r)
+
+        if not "error" in data:
+            course = Course(int(data["course_id"]), data["course_name"])
+            exercise = Exercise(course, int(data["exercise_id"]), data["exercise_name"])
+            exercise.setDownloaded()
+            exercise.setDeadline(data["deadline"], data["deadline"])
+            return exercise
+
+        v.log(-1, "Could not find exercise %d" % exercise)
         return None
 
     def download_exercises(self, exercises):
@@ -152,7 +162,9 @@ class Connection:
         s = subprocess.Popen(["ant", "test", "-S"], stdout=open(os.devnull, "wb"), stderr=open(os.devnull, "wb"), cwd=os.path.join(os.getcwd(), exercise.course.name, exercise.name_week, exercise.name_name))
         s.communicate()
 
-        for filename in glob.glob("%s*.xml" % (os.path.join(exercise.course.name, exercise.name_week, exercise.name_name, "build", "test", "results") + os.sep)):
+        files = glob.glob("%s*.xml" % (os.path.join(exercise.course.name, exercise.name_week, exercise.name_name, "build", "test", "results") + os.sep))
+
+        for filename in files:
             try:
                 with open(filename, "r") as fp:
                     root = ET.fromstring(fp.read())
@@ -168,6 +180,10 @@ class Connection:
             except IOError:
                 pass
 
+        if len(files) == 0:
+            v.log(-1, "Something wen't wrong with testing!")
+            exit(-1)
+
     def submit_exercise(self, exercise, callback):
         if exercise.downloaded == False:
             v.log(-1, """Can't submit something you have not even downloaded. 
@@ -221,6 +237,11 @@ class Connection:
             callback(data)
         return data["status"]
 
+    def select_course(self):
+        data = self.get_courses()
+        char = sys.stdin.read(1)
+        print 'You pressed %s' % char
+
     def spin(self):
         if self.spinindex != 0:
             sys.stdout.write("\b")
